@@ -238,13 +238,13 @@ class DataLoader:
                         datas[i].append(b[keys[i]])
                 for i, data in enumerate(datas):
                     if types[i] in {np.ndarray, list, tuple, int, float}:
-                        max_len = np.amax(np.array([len(d) if hasattr(d, "__len__") else 1 for d in data]), axis=0)
-                        min_len = np.amin(np.array([len(d) if hasattr(d, "__len__") else 1 for d in data]), axis=0)
-                        if np.all(max_len == min_len):
+                        max_shape = np.amax(np.array([np.shape(d) if hasattr(d, "__len__") else 1 for d in data]), axis=0)
+                        min_shape = np.amin(np.array([np.shape(d) if hasattr(d, "__len__") else 1 for d in data]), axis=0)
+                        if np.all(max_shape == min_shape):
                             datas[i] = np.array(data)
                         else:
-                            padded_begin = np.zeros(max_len.shape).astype(np.int32)
-                            datas[i] = np.array([np.pad(d, np.stack((padded_begin, max_len - len(d))).T, constant_values=self._padding_value) for d in data])
+                            padded_begin = np.zeros(max_shape.shape).astype(np.int32)
+                            datas[i] = np.array([np.pad(d, np.stack((padded_begin, max_shape - np.shape(d))).T, constant_values=self._padding_value) for d in data])
                     elif types[i] is dict:
                         tmp_dict = {k: [] for k in data[0].keys()}
                         for d in data:
